<?php
/**
 * Adds links for Perfect Checkout on the plugins page.
 *
 * @author  Sébastien Dumont
 * @package Perfect Checkout\Admin
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Perfect_Checkout_Admin_Action_Links' ) ) {

	class Perfect_Checkout_Admin_Action_Links {

		/**
		 * Constructor
		 *
		 * @access public
		 */
		public function __construct() {
			add_filter( 'plugin_action_links_' . plugin_basename( PERFECTCHECKOUT_FILE ), array( $this, 'plugin_action_links' ) );
		} // END __construct()

		/**
		 * Plugin action links.
		 *
		 * @access public
		 * @param  array $links An array of plugin links.
		 * @return array $links
		 */
		public function plugin_action_links( $links ) {
			if ( current_user_can( 'manage_options' ) ) {
				$action_links = array(
					'settings' => '<a href="' . add_query_arg(
						array(
							'page' => 'perfect-checkout',
						),
						admin_url( 'admin.php' )
					) . '" aria-label="' . sprintf( esc_attr__( 'Settings for %s', 'perfect-checkout' ), 'Perfect Checkout' ) . '">' . esc_attr__( 'Settings', 'perfect-checkout' ) . '</a>',
				);

				return array_merge( $action_links, $links );
			}

			return $links;
		} // END plugin_action_links()

	} // END class

} // END if class exists

return new Perfect_Checkout_Admin_Action_Links();
