<?php
/**
 * Perfect Checkout Settings
 *
 * @author  Sébastien Dumont
 * @package Perfect Checkout\Admin\Settings
 * @since   1.0.0
 * @version 1.4.0
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Perfect_Checkout_Settings' ) ) {

	class Perfect_Checkout_Settings extends Perfect_Checkout_Settings_Page {

		/**
		 * Constructor.
		 *
		 * @access  public
		 */
		public function __construct() {
			$this->id    = 'general';
			$this->label = esc_html__( 'Perfect Checkout', 'perfect-checkout' );

			parent::__construct();
		} // END __construct()

		/**
		 * Get settings array.
		 *
		 * @access  public
		 * @since   1.0.0
		 * @version 1.4.0
		 * @return  array
		 */
		public function get_settings() {
			$pc_license = get_option( 'perfectcheckout_license' );
			$pc_active  = get_option( 'perfectcheckout_set_active', 'no' );

			$connect_url = 'https://my.perfectcheckout.com/user/connect-license';

			if ( defined( 'PERFECTCHECKOUT_DEBUG' ) ) {
				$connect_url = 'https://prelive.perfectcheckout.com/user/connect-license';
			}

			$connect_url = add_query_arg( array(
				'site' => get_site_url()
			), $connect_url );

			$settings = array();

			if ( empty( $pc_license ) ) {
				$settings[] = array(
					'title' => esc_html__( 'Connect Account', 'perfect-checkout' ),
					'type' => 'title',
					'desc' => sprintf( esc_html__( 'Go back to %s to complete the connection with your account.', 'perfect-checkout' ), 'Perfect Checkout' ),
					'id'   => 'licence_key',
				);

				$settings[] = array(
					'type'     => 'button',
					'value'    => esc_html__( 'Connect', 'perfect-checkout' ),
					'url'      => $connect_url,
					'class'    => 'button-large perfect-button',
					'id'       => 'perfectcheckout_license',
					'autoload' => false,
				);
			} else {
				$settings[] = array(
					'type' => 'title',
					'id'   => 'licence_key',
				);

				$settings[] = array(
					'title'    => esc_html__( 'License Key', 'perfect-checkout' ),
					'id'       => 'perfectcheckout_license',
					'type'     => 'text',
					'default'  => '',
					'css'      => 'min-width:340px;',
					'class'    => 'required',
					'desc'     => __( 'Note: Your license is good for 1 connected store at a time.', 'perfect-checkout' ),
					'disabled' => true,
					'autoload' => false,
				);

				$disconnect_url = wp_nonce_url( add_query_arg( array(
					'page'          => 'perfect-checkout',
					'pc-disconnect' => true,
				), admin_url( 'admin.php' ) ), 'disconnect-perfectcheckout' );

				$settings[] = array(
					'type'     => 'button',
					'value'    => esc_html__( 'Disconnect', 'perfect-checkout' ),
					'url'      => $disconnect_url,
					'class'    => 'button-large perfect-button',
					'desc'     => __( 'Disconnect if you want to connect to another account.', 'perfect-checkout' ),
					'id'       => 'perfectcheckout_disconnect',
					'autoload' => false,
				);
			}

			$settings[] = array(
				'type' => 'sectionend',
				'id'   => 'licence_key',
			);

			if ( ! empty( $pc_license ) ) {
				$settings[] = array(
					'title' => esc_html__( 'Ready for Perfect Checkout?', 'perfect-checkout' ),
					'type'  => 'title',
					'desc'  => esc_html__( 'Press "Activate" when ready to increase your conversion rates.', 'perfect-checkout' ),
					'id'    => 'checkout_page',
				);

				if ( 'yes' === $pc_active ) {
					$switch_checkout_url = wp_nonce_url( add_query_arg( array(
						'page'     => 'perfect-checkout',
						'checkout' => 'default',
					), admin_url( 'admin.php' ) ), 'switch-checkout' );

					$settings[] = array(
						'type'     => 'button',
						'value'    => sprintf(
							/* translators: %s Perfect Checkout */
							esc_html__( 'Disable %s', 'perfect-checkout' ),
							'Perfect Checkout'
						),
						'url'      => $switch_checkout_url,
						'class'    => 'perfect-button',
						'desc'     => sprintf( 
							/* translators: %s Perfect Checkout */
							esc_html__( '%s is now handling your cart and checkout needs. ✔️', 'perfect-checkout' ),
							'Perfect Checkout'
						),
						'id'       => 'perfectcheckout_page',
						'autoload' => false,
					);
				} else {
					$switch_checkout_url = wp_nonce_url( add_query_arg( array(
						'page'     => 'perfect-checkout',
						'checkout' => 'perfect',
					), admin_url( 'admin.php' ) ), 'switch-checkout' );

					$settings[] = array(
						'type'     => 'button',
						'value'    => esc_html__( 'Activate', 'perfect-checkout' ),
						'url'      => $switch_checkout_url,
						'class'    => 'perfect-button',
						'id'       => 'perfectcheckout_page',
						'autoload' => false,
					);
				}

				$settings[] = array(
					'type' => 'sectionend',
					'id'   => 'checkout_page',
				);

				$settings[] = array(
					'title' => esc_html__( 'Google Analytics', 'perfect-checkout' ),
					'type'  => 'title',
					'desc'  => esc_html__( 'Enter your Google Analytics tracking ID so Perfect Checkout can help you track customers actions.', 'perfect-checkout' ),
					'id'    => 'google_analytics',
				);

				$settings[] = array(
					// 'title'    => esc_html__( 'Google Analytics Tracking ID', 'perfect-checkout' ),
					'id'          => 'perfectcheckout_google_analytics',
					'type'        => 'text',
					'default'     => '',
					'css'         => 'width:100%;',
					'desc'        => esc_html__( 'This can be found in your Google Analytics account settings.', 'perfect-checkout' ),
					'placeholder' => 'G-QN6BTJ6W0S',
					'autoload'    => false,
				);

				$settings[] = array(
					'type' => 'sectionend',
					'id'   => 'google_analytics',
				);

				$settings[] = array(
					'title' => esc_html__( 'Checkout Now', 'perfect-checkout' ),
					'type'  => 'title',
					'desc'  => esc_html__( 'Let your customers checkout instantly by enabling our checkout now buttons.', 'perfect-checkout' ),
					'id'    => 'checkout_now',
				);

				$settings[] = array(
					'title'   => '',
					'desc'    => __( 'Enable "Checkout Now" buttons on shop page.', 'perfect-checkout' ),
					'id'      => 'perfectcheckout_shop_checkout_button',
					'default' => 'no',
					'type'    => 'checkbox',
				);

				$settings[] = array(
					'title'   => '',
					'desc'    => __( 'Enable "Checkout Now" button on product pages.', 'perfect-checkout' ),
					'id'      => 'perfectcheckout_checkout_button',
					'default' => 'no',
					'type'    => 'checkbox',
				);

				$settings[] = array(
					'type' => 'sectionend',
					'id'   => 'checkout_now',
				);
			}

			return $settings;
		} // END get_settings()

		/**
		 * Output the settings.
		 *
		 * @access public
		 */
		public function output() {
			$settings = $this->get_settings();

			Perfect_Checkout_Admin_Settings::output_fields( $settings );
		} // END output()

		/**
		 * Save settings.
		 *
		 * @access public
		 */
		public function save() {
			$settings = $this->get_settings();

			Perfect_Checkout_Admin_Settings::save_fields( $settings );
		} // END save()

	} // END class

} // END if class exists

return new Perfect_Checkout_Settings();
