<?php
/**
 * Admin Modal: Deactivation intent form template.
 *
 * @author  Sébastien Dumont
 * @package Perfect Checkout\Admin\Views
 * @since   1.0.7
 * @version 1.1.2
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$plugin_file = plugin_basename( PERFECTCHECKOUT_FILE );

$deactivation_url = wp_nonce_url( add_query_arg( array(
	'action' => 'deactivate',
	'plugin' => rawurlencode( $plugin_file ),
), admin_url( 'plugins.php' ) ), 'deactivate-plugin_' . $plugin_file );

// Reasons.
$reasons = array(
	array(
		'id'           => 'temporary',
		'value'        => esc_html__( 'Temporary Deactivation', 'perfect-checkout' ),
		'label'        => sprintf( __( '%1$sIt is a temporary deactivation.%2$s I am just debugging an issue.', 'perfect-checkout' ), '<strong>', '</strong>' ),
		'hidden_field' => 'no',
	),
	array(
		'id'           => 'too-complicated',
		'value'        => esc_html__( 'Too Complicated', 'perfect-checkout' ),
		'label'        => sprintf( __( 'The plugin is %1$stoo complicated to configure.%2$s', 'perfect-checkout' ), '<strong>', '</strong>' ),
		'hidden_field' => 'no',
		'reason'       => array(
			'title'   => esc_html__( 'The plugin is too complicated to configure.', 'perfect-checkout' ),
			'content' => '<p>' . esc_html__( 'We are sorry to hear you are finding it difficult to use Perfect Checkout.', 'perfect-checkout' ) . '</p>' .
						'<p>' . sprintf( __( 'We do our best to make Perfect Checkout provide the best checkout flow out there. If there is something we can do to help make it less complicated, %1$splease write to us%2$s and let us know.', 'perfect-checkout' ), '<a href="https://perfectcheckout.com/contact-us/" target="_blank">', '</a>' ) . '</p>',
		),
	),
	array(
		'id'                 => 'another-plugin',
		'value'              => esc_html__( 'Another Plugin', 'perfect-checkout' ),
		'label'              => esc_html__( 'I\'m using another plugin I find better.', 'perfect-checkout' ),
		'hidden_field'       => 'yes',
		'hidden_placeholder' => esc_html__( 'What is the name of this plugin?', 'perfect-checkout' ),
	),
);
?>
<!-- Start of Perfect Checkout Modal -->
<div class="perfect-checkout-modal">

	<div class="perfect-checkout-modal-header">
		<div>
			<button class="perfect-checkout-modal-return perfect-checkout-icon-arrow-left"><?php esc_html_e( 'Return', 'perfect-checkout' ); ?></button>
			<h2><?php esc_html_e( 'Perfect Checkout Feedback', 'perfect-checkout' ); ?></h2>
		</div>
		<button class="perfect-checkout-modal-close perfect-checkout-icon-close"><?php esc_html_e( 'Close', 'perfect-checkout' ); ?></button>
	</div>

	<div class="perfect-checkout-modal-content">
		<div class="perfect-checkout-modal-question perfect-checkout-isOpen">
			<h3><?php esc_html_e( 'Would you mind telling us why you are deactivating so we can improve?', 'perfect-checkout' ); ?></h3>
			<ul>
				<?php
				// List each possible reason.
				foreach ( $reasons as $reason ) {
					echo '<li>';

					echo '<input type="radio" name="reason" id="reason-' . esc_html( $reason['id'] ) . '" value="' . esc_attr( $reason['value'] ) . '">';
					echo '<label for="reason-' . esc_html( $reason['id'] ) . '">' . wp_kses_post( $reason['label'] ) . '</label>';

					if ( 'yes' === $reason['hidden_field'] ) {
						echo '<div class="perfect-checkout-modal-fieldHidden"><input type="text" name="reason-' . esc_html( $reason['id'] ) . '" id="reason-' . esc_html( $reason['id'] ) . '" value="" placeholder="' . wp_kses_post( $reason['hidden_placeholder'] ) . '"></div>';
					}

					echo '</li>';
				}
				?>
				<li>
					<input type="radio" name="reason" id="reason-other" value="Other">
					<label for="reason-other"><?php esc_html_e( 'Other', 'perfect-checkout' ); ?></label>
					<div class="perfect-checkout-modal-fieldHidden">
						<textarea name="reason-other-details" id="reason-other-details" placeholder="<?php esc_html_e( 'Let us know why you are deactivating Perfect Checkout so we can improve the plugin.', 'perfect-checkout' ); ?>"></textarea>
					</div>
				</li>
			</ul>
			<input id="perfect-checkout-reason" type="hidden" value="">
			<input id="perfect-checkout-details" type="hidden" value="">
		</div>

		<?php
		// Prepare response to reason if any.
		foreach ( $reasons as $reason ) {
			if ( isset( $reason['reason'] ) ) {
				echo '<div id="reason-' . esc_html( $reason['id'] ) . '-panel" class="perfect-checkout-modal-hidden">';
				echo '<h3>' . esc_attr( $reason['reason']['title'] ) . '</h3>';
				echo wp_kses_post( $reason['reason']['content'] );
				echo '</div>';
			}
		}
		?>
	</div>

	<div class="perfect-checkout-modal-footer">
		<div>
			<a href="<?php echo esc_attr( $deactivation_url ); ?>" class="button button-primary perfect-checkout-isDisabled" disabled id="send-deactivation"><?php esc_html_e( 'Send & Deactivate', 'perfect-checkout' ); ?></a>
			<button class="perfect-checkout-modal-cancel"><?php esc_html_e( 'Cancel', 'perfect-checkout' ); ?></button>
		</div>
		<a href="<?php echo esc_attr( $deactivation_url ); ?>" class="button button-secondary"><?php esc_html_e( 'Skip & Deactivate', 'perfect-checkout' ); ?></a>

		<input type="hidden" id="ajax_url" value="<?php echo admin_url( 'admin-ajax.php' ); ?>" />
	</div>

</div>

<div class="perfect-checkout-modal-overlay"></div>
<!-- End of Perfect Checkout Modal -->
