<?php
/**
 * Perfect Checkout - Settings controller.
 *
 * Handles the request to get settings of Perfect Checkout.
 *
 * @author  Sébastien Dumont
 * @package Perfect Checkout\API
 * @since   1.3.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * REST API Settings controller class.
 *
 * @package Perfect Checkout\API
 */
class Perfect_Checkout_API_Settings_Controller {

	/**
	 * Endpoint namespace.
	 *
	 * @var string
	 */
	protected $namespace = 'pc/connect';

	/**
	 * Route base.
	 *
	 * @var string
	 */
	protected $rest_base = 'settings';

	/**
	 * Register routes.
	 *
	 * @access public
	 */
	public function register_routes() {
		register_rest_route(
			$this->namespace,
			'/' . $this->rest_base,
			array(
				'methods'             => WP_REST_Server::READABLE,
				'callback'            => array( $this, 'settings_callback' ),
				'permission_callback' => array( $this, 'get_items_permissions_check' ),
			)
		);
	} // register_routes()

	/**
	 * Check whether a given request has permission to read info.
	 *
	 * @access public
	 */
	public function get_items_permissions_check( $request ) {
		if ( ! wc_rest_check_user_permissions( 'read' ) ) {
			return new WP_Error( 'perfectcheckout_rest_cannot_view', __( 'Sorry, you cannot list resources.', 'perfect-checkout' ), array( 'status' => rest_authorization_required_code() ) );
		}

		return true;
	} // END get_items_permissions_check()

	/**
	 * Returns settings of Perfect Checkout.
	 *
	 * @access public
	 * @param  WP_REST_Request $request Full details about the request.
	 * @return WP_REST_Response
	 */
	public function settings_callback( $request ) {
		require_once dirname( PERFECTCHECKOUT_FILE ) . '/includes/admin/settings/class-perfect-checkout-settings-page.php';
		require_once dirname( PERFECTCHECKOUT_FILE ) . '/includes/admin/settings/class-perfect-checkout-settings.php';

		$pc_settings = new Perfect_Checkout_Settings();
		$pc_settings = $pc_settings->get_settings();

		$settings = array();

		foreach ( $pc_settings as $setting ) {
			// Return all settings excluding title and section end.
			if ( ! in_array( $setting['type'], array( 'title', 'sectionend' ) ) ) {
				$settings[$setting['id']] = get_option( $setting['id'], null );
			}
		}

		// Response.
		$response = rest_ensure_response( $settings );
		$response->set_status( 200 );

		return $response;
	} // END settings_callback()

} // END class
