<?php
/**
 * Perfect Checkout Page Functions
 *
 * Functions related to pages.
 *
 * @author  Sébastien Dumont
 * @package Perfect Checkout\Functions
 * @since   1.0.2
 * @version 1.4.0
 * @license GPL-2.0+
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'get_perfect_checkout_page_id' ) ) {
	/**
	 * Returns the Perfect Checkout page ID if one is found.
	 *
	 * @since  1.4.0
	 * @return int
	 */
	function get_perfect_checkout_page_id() {
		$page_id = get_option( 'perfectcheckout_page_id' );

		return 0 < $page_id ? absint( $page_id ) : '';
	}
}

if ( ! function_exists( 'is_perfect_checkout' ) ) {
	/**
	 * Returns true when viewing the Perfect Checkout page.
	 *
	 * @since   1.0.2
	 * @version 1.4.0
	 * @return  bool
	 */
	function is_perfect_checkout() {
		$page_id = get_perfect_checkout_page_id();

		return ( $page_id && is_page( $page_id ) );
	}
}

if ( ! function_exists( 'pc_get_checkout_url' ) ) {
	/**
	 * Gets the url to the Perfect Checkout page.
	 *
	 * @since   1.2.0
	 * @version 1.4.0
	 * @return  string Url to Perfect Checkout page.
	 */
	function pc_get_checkout_url() {
		$checkout_url = get_permalink( get_perfect_checkout_page_id() );

		if ( ! empty( $checkout_url ) ) {
			// Force SSL if needed.
			if ( is_ssl() || 'yes' === get_option( 'woocommerce_force_ssl_checkout' ) ) {
				$checkout_url = str_replace( 'http:', 'https:', $checkout_url );
			}
		}

		return $checkout_url;
	}
}
