<?php
/**
 * Template Name: Perfect Checkout.
 *
 * Loads PerfectCheckout iframe.
 *
 * @package Perfect Checkout\Templates
 * @version 1.5.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

$cart_key = WC()->session->get_customer_unique_id();

// Return requested cart key if set.
$cart_key = ! empty( $_REQUEST['pc-key'] ) ? $_REQUEST['pc-key'] : $cart_key;

$pc_license     = get_option( 'perfectcheckout_license' );
$ga_tracking_id = get_option( 'perfectcheckout_google_analytics' );

// API URL.
$api_url = PerfectCheckout::get_api_url();

// Passes arguments for iFrame.
$frame_url = add_query_arg( array(
	'pc_version' => PERFECTCHECKOUT_VERSION,
	'lang'       => get_locale(),
	'text_dir'   => function_exists( 'is_rtl' ) && is_rtl() ? 'rtl' : 'ltr',
	'id'         => $pc_license, // Perfect Checkout account ID.
	'ck'         => $cart_key, // Cart key.
), $api_url );

// Allow third parties to apply additional arguments.
$frame_url = add_query_arg( apply_filters( 'perfect_checkout_additional_arguments', array() ), $frame_url );

$shop_page_url = get_permalink( wc_get_page_id( 'shop' ) );

// Variables.
$suffix = SCRIPT_DEBUG ? '' : '.min';
$top    = '0';

// If admin bar is showing, position checkout down by 32px.
if ( is_admin_bar_showing() ) {
	$top = '32';
}
?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
	<head>
		<meta charset="<?php bloginfo( 'charset' ); ?>" />
		<meta
			name="viewport"
			content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0"
		/>
		<title><?php echo esc_html( get_bloginfo( 'name', 'display' ) . ' - ' . __( 'Checkout', 'perfect-checkout' ) ); ?></title>
		<?php if ( is_admin_bar_showing() ) { ?>
		<link rel="stylesheet" id="dashicons" href="<?php echo get_site_url(); ?>/wp-includes/css/dashicons<?php echo $suffix; ?>.css" media="all">
		<link rel="stylesheet" id="admin-bar" href="<?php echo get_site_url(); ?>/wp-includes/css/admin-bar<?php echo $suffix; ?>.css" media="all">
		<style type="text/css">
		#wp-admin-bar-customize,
		#wp-admin-bar-comments,
		#wp-admin-bar-edit,
		#wp-admin-bar-cxssh-main-menu,
		#wp-admin-bar-wpseo-menu,
		#wp-admin-bar-query-monitor,
		#wp-admin-bar-tm-suspend { display: none; }
		</style>
		<?php } ?>
		<script type="text/javascript">
			window.addEventListener('message', function(event) {
				if (event.data && event.data.message) {
					console.log('message: ' + event.data.message);
					if (event.data.message === "back") {
						window.location.href = '<?php echo esc_url( $shop_page_url ); ?>';
					}
					else if (event.data.message === "logout") {
						window.location.href = '<?php echo add_query_arg( 'pc-logout', 1, pc_get_checkout_url() ); ?>';
					}
					else if (event.data.message.startsWith("login")) {
						const credentials = event.data.message.slice(6);
						window.location.href = `<?php echo pc_get_checkout_url(); ?>?pc-login=${credentials}`;
					}
				}
			});
		</script>

		<?php if ( ! empty( $ga_tracking_id ) ) { ?>
		<!-- Global site tag (gtag.js) - Google Analytics -->
		<script async src="https://www.googletagmanager.com/gtag/js?id=<?php echo $ga_tracking_id; ?>"></script>
		<script>
		window.dataLayer = window.dataLayer || [];
		function gtag(){dataLayer.push(arguments);}
		gtag('js', new Date());

		gtag('config', '<?php echo $ga_tracking_id; ?>');
		</script>
		<?php } ?>
	</head>

	<body>
		<div style="min-height: 100vh; display: flex; flex-direction: column; position: fixed; width: 100%; top: <?php echo $top; ?>px; left: 0;">
			<iframe class="skip-lazy" src='<?php echo esc_url( $frame_url ); ?>' title='Perfect Checkout Window' referrerpolicy="origin" id="perfect-frame" width="100%" allow="payment *"
				style="flex: 1 0 auto; outline: none; border: none; height: 100%; height: -webkit-fill-available; overflow: hidden; overscroll-behavior: none !important; -webkit-overflow-scrolling: none !important;">	  
			</iframe>
		</div>

		<?php
		if ( is_admin_bar_showing() ) {
			echo wp_admin_bar_render();
		}
		?>

	</body>
</html>
